@@ -241,6 +241,7 @@ ask_user (GDBusMethodInvocation *invocation,
 						notification_text,
 						"bluetooth");
 
+	notify_notification_set_urgency (notification, NOTIFY_URGENCY_CRITICAL);
 	notify_notification_set_timeout (notification, NOTIFY_EXPIRES_NEVER);
 	notify_notification_set_hint_string (notification, "desktop-entry",
 					     "gnome-bluetooth-panel");
@@ -740,7 +741,7 @@ on_bus_acquired (GDBusConnection *connection,
 
 	self->obexd_watch_id = g_bus_watch_name_on_connection (self->connection,
 							       MANAGER_SERVICE,
-							       G_BUS_NAME_WATCHER_FLAGS_NONE,
+							       G_BUS_NAME_WATCHER_FLAGS_AUTO_START,
 							       obexd_appeared_cb,
 							       NULL,
 							       self,
@@ -798,6 +799,9 @@ obex_agent_new (void)
 void
 obex_agent_down (void)
 {
+	if (agent == NULL)
+		return;
+
 	g_dbus_connection_call (agent->connection,
 				MANAGER_SERVICE,
 				MANAGER_PATH,
@@ -814,7 +818,7 @@ obex_agent_down (void)
 	g_clear_object (&agent);
 }
 
-gboolean
+void
 obex_agent_up (void)
 {
 	if (agent == NULL)
@@ -823,8 +827,6 @@ obex_agent_up (void)
 	if (!notify_init("gnome-user-share")) {
 		g_warning("Unable to initialize the notification system");
 	}
-
-	return agent != NULL;
 }
 
 void
